import sys
import traceback
import requests
from charmhelpers.core.hookenv import (
    action_get,
    action_fail,
    action_set,
    status_set,
    config
)
from charms.reactive import (
    clear_flag,
    set_flag,
    when,
    when_not,
)

@when_not('http-config.installed')
def install_http_config_charm():
    set_flag('http-config.installed')
    status_set('active', 'Ready!')

@when('actions.create-file')
def create_file():
    try:
        ip = config()['ssh-hostname']
        filename = action_get('filename')
        content = action_get('content')

        url = 'http://{}:5000/file'.format(ip)
        body = {
            'name': filename,
            'content': content
        }

        result = requests.post(url, json=body)

        if result.status > 250:
            result.raise_for_status()
    except:
        exc_type, exc_value, exc_traceback = sys.exc_info()
        err = traceback.format_exception(exc_type, exc_value, exc_traceback)
        action_fail('Creating file failed: ' + str(err))
    else:
        action_set({'output': result.text})
    finally:
        clear_flag('actions.create-file')
